summaryrefslogtreecommitdiff
path: root/sw/inc/viewopt.hxx
diff options
context:
space:
mode:
authorMiklos Vajna <vmiklos@collabora.co.uk>2013-10-26 19:50:13 +0200
committerMiklos Vajna <vmiklos@collabora.co.uk>2013-10-26 20:03:50 +0200
commitee3189489c0205ec221fbc907a01c711b58fc42e (patch)
tree1cd2fd05e3518d9484b11f0fc29b6e458a629338 /sw/inc/viewopt.hxx
parent2e99447fc07df98ebbc343ef79852b7eaf7b7757 (diff)
sw: ViewShell -> SwViewShell rename
It's a public class, so it should have the 'Sw' prefix. Change-Id: I0040c1cc37ffcba7fc5f58b71c86f4a7cb0bfce4
Diffstat (limited to 'sw/inc/viewopt.hxx')
-rw-r--r--sw/inc/viewopt.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sw/inc/viewopt.hxx b/sw/inc/viewopt.hxx
index 89f2ef86c259..d916bbf8dfa6 100644
--- a/sw/inc/viewopt.hxx
+++ b/sw/inc/viewopt.hxx
@@ -33,7 +33,7 @@
class SwRect;
class Window;
class OutputDevice;
-class ViewShell;
+class SwViewShell;
class SwDocShell;
namespace svtools{ class ColorConfig;}
@@ -136,8 +136,8 @@ protected:
static sal_uInt16 nPixelTwips;// 1 Pixel == ? Twips
OUString sSymbolFont; // Symbolfont.
- sal_uInt32 nCoreOptions; // Bits for ViewShell.
- sal_uInt32 nCore2Options; // Bits for ViewShell.
+ sal_uInt32 nCoreOptions; // Bits for SwViewShell.
+ sal_uInt32 nCore2Options; // Bits for SwViewShell.
sal_uInt32 nUIOptions; // UI-Bits
Color aRetoucheColor; // DefaultBackground for BrowseView
Size aSnapSize; // Describes horizontal and vertical snap.